@@ -78,18 +78,6 @@
 #include "utils.h"
 #include <kio_version.h>
 
-QWebEngineScript WebEnginePart::detectRefreshScript() {
-    static QWebEngineScript s_detectRefreshScript;
-    if (s_detectRefreshScript.isNull()) {
-        QFile jsfile(":/hasrefresh.js");
-        jsfile.open(QIODevice::ReadOnly);
-        s_detectRefreshScript.setSourceCode(QString(jsfile.readAll()));
-        s_detectRefreshScript.setInjectionPoint(QWebEngineScript::DocumentCreation);
-        s_detectRefreshScript.setWorldId(QWebEngineScript::ApplicationWorld);
-    }
-    return s_detectRefreshScript;
-}
-
 WebEnginePart::WebEnginePart(QWidget *parentWidget, QObject *parent,
                          const KPluginMetaData& metaData,
                          const QByteArray& cachedHistory, const QStringList& /*args*/)
@@ -106,6 +94,8 @@ WebEnginePart::WebEnginePart(QWidget *parentWidget, QObject *parent,
         WebEnginePartControls::self()->setup(QWebEngineProfile::defaultProfile());
     }
 
+    connect(WebEnginePartControls::self(), &WebEnginePartControls::userAgentChanged, this, &WebEnginePart::reloadAfterUAChange);
+
     setMetaData(metaData);
 
 #if 0
@@ -1111,3 +1101,14 @@ void WebEnginePart::setInspectedPart(KParts::ReadOnlyPart* part)
     page()->setInspectedPage(wpart->page());
     setUrl(page()->url());
 }
+
+void WebEnginePart::reloadAfterUAChange(const QString &)
+{
+    if (!page()) {
+        return;
+    }
+    //NOTE: usually local files won't be affected by this, so don't automatically reload them
+    if (!url().isLocalFile() && !url().isEmpty() && url().scheme() != "konq") {
+        m_webView->triggerPageAction(QWebEnginePage::Reload);
+    }
+}
